pub fn convert_parsed(
doc: &Html,
base_url: &str,
content_type: ContentType,
) -> ConvertedExpand description
Convert a parsed document to the requested content type.
pub fn convert_parsed(
doc: &Html,
base_url: &str,
content_type: ContentType,
) -> ConvertedConvert a parsed document to the requested content type.