pub async fn fetch_page(url: &str, timeout_secs: u64) -> Result<FetchedPage>Expand description
Fetch a URL, following redirects, retrying transient failures with exponential backoff (200ms, 400ms).
pub async fn fetch_page(url: &str, timeout_secs: u64) -> Result<FetchedPage>Fetch a URL, following redirects, retrying transient failures with exponential backoff (200ms, 400ms).